WindowFunction<T> class
Configuration for window functions
- Implementers
Constructors
-
WindowFunction({required WindowFunctionType type, String? field, required String alias, List<
String> ? partitionBy, List<OrderByClause< ? orderBy, String? frameClause})T> > -
const
-
WindowFunction.fromJson(Map<
String, dynamic> json) -
factory
Properties
- alias → String
-
final
- field → String?
-
final
- frameClause → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
orderBy
→ List<
OrderByClause< ?T> > -
final
-
partitionBy
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → WindowFunctionType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited